pub enum SecioError {
Show 14 variants
IoError(Error),
Openssl(ErrorStack),
CryptoError,
NotSupportKeyProvider,
EphemeralKeyGenerationFailed,
SecretGenerationFailed,
NoSupportIntersection,
NonceVerificationFailed,
FrameTooShort,
ConnectSelf,
HandshakeParsingFailure,
SignatureVerificationFailed,
InvalidMessage,
InvalidProposition(&'static str),
}Expand description
Error at the SECIO layer communication.
Variants
IoError(Error)
I/O error.
Openssl(ErrorStack)
Openssl stack error
CryptoError
Crypto error
NotSupportKeyProvider
Sign operation not supported
EphemeralKeyGenerationFailed
Failed to generate ephemeral key.
SecretGenerationFailed
Failed to generate the secret shared key from the ephemeral key.
NoSupportIntersection
There is no protocol supported by both the local and remote hosts.
NonceVerificationFailed
The final check of the handshake failed.
FrameTooShort
The received frame was of invalid length.
ConnectSelf
Connect yourself
HandshakeParsingFailure
Failed to parse one of the handshake bincode messages.
SignatureVerificationFailed
The signature of the exchange packet doesn’t verify the remote public key.
InvalidMessage
Invalid message message found during handshake
InvalidProposition(&'static str)
We received an invalid proposition from remote.